Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Ultimaker/Cura.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorfieldOfView <aldo@fieldofview.com>2021-08-16 15:28:40 +0300
committerfieldOfView <aldo@fieldofview.com>2021-08-16 15:28:40 +0300
commitf11869034b24f506093503e04429bc2848e962f4 (patch)
treebb8e91251d00152e979cbe040bae2f1a1bd0b8d5 /plugins/CuraEngineBackend
parentd5d163377b7de2b2dc33218e9955d934b658b319 (diff)
Add {material_type} and {material_name} as replacement patterns
Diffstat (limited to 'plugins/CuraEngineBackend')
-rw-r--r--plugins/CuraEngineBackend/StartSliceJob.py4
1 files changed, 3 insertions, 1 deletions
diff --git a/plugins/CuraEngineBackend/StartSliceJob.py b/plugins/CuraEngineBackend/StartSliceJob.py
index 453907ffc0..8729bdf7be 100644
--- a/plugins/CuraEngineBackend/StartSliceJob.py
+++ b/plugins/CuraEngineBackend/StartSliceJob.py
@@ -411,8 +411,10 @@ class StartSliceJob(Job):
extruder_nr = stack.getProperty("extruder_nr", "value")
settings = self._all_extruders_settings[str(extruder_nr)].copy()
# Also send the material GUID. This is a setting in fdmprinter, but we have no interface for it.
settings["material_guid"] = stack.material.getMetaDataEntry("GUID", "")
+ settings["material_type"] = stack.material.getMetaDataEntry("material", "")
+ settings["material_name"] = stack.material.getMetaDataEntry("name", "")
# Replace the setting tokens in start and end g-code.
extruder_nr = stack.getProperty("extruder_nr", "value")
@@ -411,8 +411,10 @@ class StartSliceJob(Job):
extruder_nr = stack.getProperty("extruder_nr", "value")
settings = self._all_extruders_settings[str(extruder_nr)].copy()
- # Also send the material GUID. This is a setting in fdmprinter, but we have no interface for it.
+ # Also send the material GUID, type and name. These are settings in fdmprinter, but we have no interface for it.
settings["material_guid"] = stack.material.getMetaDataEntry("GUID", "")